window.Gleam.initSearch([{"doc":"gleamstral","title":"gleamstral","content":"# gleamstral\n\n[![Package Version](https://img.shields.io/hexpm/v/gleamstral)](https://hex.pm/packages/gleamstral)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleamstral/)\n\nA Gleam client library for the Mistral AI API, providing type-safe access to Mistral&#39;s powerful language models, embeddings, and agents.\n\n## Overview\n\nGleamstral enables Gleam applications to seamlessly integrate with Mistral AI&#39;s capabilities, including:\n\n- Chat completions with various Mistral models (Large, Small, Ministral, etc.)\n- Function/tool calling support\n- Embeddings generation\n- Agent API integration\n- Image analysis with Pixtral models\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gleamstral&gt;.\n\n## Installation\n\n```sh\ngleam add gleamstral\n```\n\n## Getting an API key\n\nYou can get an API key **for free** from Mistral [La Plateforme](https://console.mistral.ai/).\n\n## Quick Example\n\n```gleam\nimport gleam/io\nimport gleamstral/client\nimport gleamstral/chat/chat\nimport gleamstral/message\nimport gleamstral/model\n\npub fn main() {\n  // Create a Mistral client with your API key\n  let client = client.new(&quot;your-mistral-api-key&quot;)\n  \n  // Set up a chat with Mistral Large model\n  let chat_client = chat.new(client) |&gt; chat.with_temperature(0.7)\n\n  // Define a list of one or many messages to send to the model\n  let messages = [\n    message.UserMessage(message.TextContent(&quot;Explain brievly what is Gleam&quot;)),\n  ]\n\n  // Send the request and get a response from the model\n  let assert Ok(response) =\n    chat_client\n    |&gt; chat.complete(model.MistralSmall, messages)\n\n  let assert Ok(choice) = list.first(response.choices)\n  let assert message.AssistantMessage(content, _, _) = choice.message\n\n  io.println(&quot;Response: &quot; &lt;&gt; content) // &quot;Gleam is a very cool language [...]&quot;\n}\n```\n\n## Key Features\n\n### Chat Completions with Vision\n\nGleamstral supports multimodal inputs, allowing you to send both text and images to vision-enabled models like Pixtral:\n\n```gleam\n// Create a message with an image\nlet messages = [\n  message.UserMessage(\n    message.MultiContent([\n      message.Text(&quot;What&#39;s in this image?&quot;),\n      message.ImageUrl(&quot;https://gleam.run/images/lucy/lucy.svg&quot;)\n    ])\n  )\n]\n\n// Use a Pixtral model for image analysis\nlet response = chat.new(client) |&gt; chat.complete(model.PixtralLarge, messages)\n\n// Get the first choice from the response\nlet assert Ok(choice) = list.first(response.choices)\nlet assert message.AssistantMessage(content, _, _) = choice.message\n\nio.println(&quot;Response: &quot; &lt;&gt; content) // &quot;This is a picture of the cute star lucy&quot;\n```\n\n### Agent API\n\nAccess Mistral&#39;s Agent API to utilize pre-configured agents for specific tasks:\n\n```gleam\n// Get your agent ID from the Mistral console\nlet agent_id = &quot;your-agent-id&quot;\n\n// Call the agent with your agent ID and messages\nlet response = agent.new(client) |&gt; agent.complete(agent_id, messages)\n```\n\n### Embeddings Generation\n\nGenerate vector embeddings for text to enable semantic search, clustering, or other vector operations:\n\n```gleam\n// Generate embeddings for a text input\nembeddings.new(client)\n|&gt; embeddings.create(model.MistralEmbed, [&quot;Your text to embed&quot;])\n```\n\n### Tool/Function Calling\n\nDefine tools that the model can use to call functions in your application:\n\n```gleam\n// Define a tool\nlet weather_tool = tool.new(\n  &quot;get_weather&quot;,\n  &quot;Get the current weather in a location&quot;,\n  // Define the parameters schema\n  [#(&quot;location&quot;, String, True, &quot;The city and country, e.g. Seoul, South Korea&quot;)]\n)\n\n// Create a chat client with the tool\nlet response = chat.new(client)\n|&gt; chat.with_tools([weather_tool])\n|&gt; chat.complete(model.MistralSmall, messages)\n```\n\n## Examples\n\nThe `examples/` directory contains several ready-to-use examples demonstrating the library&#39;s capabilities:\n\n- `agent.gleam`: Shows how to use the Mistral Agent API\n- `basic_tool.gleam`: Demonstrates tool/function calling functionality\n- `embeddings.gleam`: Illustrates how to generate and use embeddings\n- `image_analysis.gleam`: Shows how to perform image analysis with Pixtral models\n- `json_object.gleam`: Example of structured JSON output from the model\n\nTo run any example:\n\n```sh\ncd examples\ngleam run -m example_name  # e.g., gleam run -m agent\n```\n\nNote: You&#39;ll need to set your Mistral API key in an `.env` file or as an environment variable.\n\n## Roadmap\n\n- [ ] Add support and example for streaming responses\n- [ ] Add support for structured outputs (JSON, JSON Schema, etc.)\n- [ ] Add more tests and documentation\n\n## Contributing\n\nContributions are welcome! Please open an issue or submit a pull request.\n\n## License\n\nThis project is licensed under the MIT License.\n","url":"index.html"},{"doc":"gleamstral/tool","title":"FunctionCall","content":"pub type FunctionCall {\n  FunctionCall(name: String, arguments: String)\n}\n Represents a function call within a tool call\n\n Contains the name of the function and its arguments as a JSON string\nFunctionCall(name: String, arguments: String)\n\n\nSynonyms:\ngleamstral/tool.FunctionCall\ngleamstral/tool FunctionCall","url":"gleamstral/tool.html#FunctionCall"},{"doc":"gleamstral/tool","title":"ParameterProperty","content":"pub type ParameterProperty {\n  ParameterProperty(param_type: String)\n}\n Property definition for a tool parameter\nParameterProperty(param_type: String)\n\n\nSynonyms:\ngleamstral/tool.ParameterProperty\ngleamstral/tool ParameterProperty","url":"gleamstral/tool.html#ParameterProperty"},{"doc":"gleamstral/tool","title":"Tool","content":"pub type Tool {\n  Function(\n    name: String,\n    description: String,\n    strict: Bool,\n    parameters: ToolParameters,\n  )\n}\n Represents a tool that can be used by the model\n\n - `Function`: A function tool with name, description, and parameters\nFunction(\n  name: String,\n  description: String,\n  strict: Bool,\n  parameters: ToolParameters,\n)\n\n\nSynonyms:\ngleamstral/tool.Tool\ngleamstral/tool Tool","url":"gleamstral/tool.html#Tool"},{"doc":"gleamstral/tool","title":"ToolCall","content":"pub type ToolCall {\n  ToolCall(\n    id: String,\n    tool_type: String,\n    function: FunctionCall,\n    index: Int,\n  )\n}\n Represents a tool call made by the model\n\n Contains the ID, type, function call details, and index of the tool call\nToolCall(\n  id: String,\n  tool_type: String,\n  function: FunctionCall,\n  index: Int,\n)\n\n\nSynonyms:\ngleamstral/tool.ToolCall\ngleamstral/tool ToolCall","url":"gleamstral/tool.html#ToolCall"},{"doc":"gleamstral/tool","title":"ToolChoice","content":"pub type ToolChoice {\n  Auto\n  None\n  Any\n  Required\n  Choice(Tool)\n}\n Tool choice options for API requests\n\n - `Auto`: Let the model decide when to use tools\n - `None`: Do not use tools\n - `Any`: Allow the model to use any available tool\n - `Required`: Require the model to use tools\n - `Choice(Tool)`: Require the model to use a specific tool\nAuto\n\n\nNone\n\n\nAny\n\n\nRequired\n\n\nChoice(Tool)\n\n\nSynonyms:\ngleamstral/tool.ToolChoice\ngleamstral/tool ToolChoice","url":"gleamstral/tool.html#ToolChoice"},{"doc":"gleamstral/tool","title":"ToolParameters","content":"pub type ToolParameters {\n  ToolParameters(\n    tool_type: String,\n    properties: List(#(String, ParameterProperty)),\n    required: List(String),\n    additional_properties: Bool,\n  )\n}\n Parameters for a tool function\n\n Contains the structure of parameters expected by the tool\nToolParameters(\n  tool_type: String,\n  properties: List(#(String, ParameterProperty)),\n  required: List(String),\n  additional_properties: Bool,\n)\n\n\nSynonyms:\ngleamstral/tool.ToolParameters\ngleamstral/tool ToolParameters","url":"gleamstral/tool.html#ToolParameters"},{"doc":"gleamstral/tool","title":"create_function_tool","content":"pub fn create_function_tool(\n  name: String,\n  description: String,\n  strict: Bool,\n  property_types: List(#(String, String)),\n  required: List(String),\n  additional_properties: Bool,\n) -&gt; Tool\n Create a function tool with parameters\n\n ### Example\n\n \n let weather_tool = tool.create_function_tool(\n   name: &quot;get_weather&quot;,\n   description: &quot;Get current temperature for provided coordinates in celsius.&quot;,\n   strict: True,\n   property_types: [\n     #(&quot;latitude&quot;, &quot;number&quot;),\n     #(&quot;longitude&quot;, &quot;number&quot;),\n   ],\n   required: [&quot;latitude&quot;, &quot;longitude&quot;],\n   additional_properties: False,\n )\n \nSynonyms:\ngleamstral/tool.create_function_tool\ngleamstral/tool create_function_tool","url":"gleamstral/tool.html#create_function_tool"},{"doc":"gleamstral/tool","title":"tool_call_decoder","content":"pub fn tool_call_decoder() -&gt; Decoder(ToolCall)\n Decodes a tool call from JSON\n\n Used to parse tool calls in model responses\nSynonyms:\ngleamstral/tool.tool_call_decoder\ngleamstral/tool tool_call_decoder","url":"gleamstral/tool.html#tool_call_decoder"},{"doc":"gleamstral/tool","title":"tool_calls_encoder","content":"pub fn tool_calls_encoder(\n  tool_calls: Option(List(ToolCall)),\n) -&gt; Json\n\nSynonyms:\ngleamstral/tool.tool_calls_encoder\ngleamstral/tool tool_calls_encoder","url":"gleamstral/tool.html#tool_calls_encoder"},{"doc":"gleamstral/tool","title":"tool_choice_encoder","content":"pub fn tool_choice_encoder(tool_choice: ToolChoice) -&gt; Json\n\nSynonyms:\ngleamstral/tool.tool_choice_encoder\ngleamstral/tool tool_choice_encoder","url":"gleamstral/tool.html#tool_choice_encoder"},{"doc":"gleamstral/tool","title":"tool_encoder","content":"pub fn tool_encoder(tool: Tool) -&gt; Json\n\nSynonyms:\ngleamstral/tool.tool_encoder\ngleamstral/tool tool_encoder","url":"gleamstral/tool.html#tool_encoder"},{"doc":"gleamstral/tool","title":"gleamstral/tool","content":"","url":"gleamstral/tool.html"},{"doc":"gleamstral/message","title":"ContentPart","content":"pub type ContentPart {\n  Text(String)\n  ImageUrl(String)\n}\n Individual content part in a multi-modal message\n\n - `Text`: Text content\n - `ImageUrl`: URL pointing to an image or a base64 encoded image string\nText(String)\n\n\nImageUrl(String)\n\n\nSynonyms:\ngleamstral/message.ContentPart\ngleamstral/message ContentPart","url":"gleamstral/message.html#ContentPart"},{"doc":"gleamstral/message","title":"Message","content":"pub type Message {\n  SystemMessage(content: MessageContent)\n  UserMessage(content: MessageContent)\n  AssistantMessage(\n    content: String,\n    tool_calls: Option(List(tool.ToolCall)),\n    prefix: Bool,\n  )\n  ToolMessage(\n    content: MessageContent,\n    tool_call_id: String,\n    name: String,\n  )\n}\n Represents a message in a conversation with the AI model\n\n - `SystemMessage`: Instructions or context for the model\n - `UserMessage`: Input from the user to the model\n - `AssistantMessage`: Response from the model, potentially including tool calls\n - `ToolMessage`: Result of a tool function execution\nSystemMessage(content: MessageContent)\n\n\nUserMessage(content: MessageContent)\n\n\nAssistantMessage(\n  content: String,\n  tool_calls: Option(List(tool.ToolCall)),\n  prefix: Bool,\n)\n\n\nToolMessage(\n  content: MessageContent,\n  tool_call_id: String,\n  name: String,\n)\n\n\nSynonyms:\ngleamstral/message.Message\ngleamstral/message Message","url":"gleamstral/message.html#Message"},{"doc":"gleamstral/message","title":"MessageContent","content":"pub type MessageContent {\n  TextContent(String)\n  MultiContent(List(ContentPart))\n}\n Content of a message, which can be text-only or multi-modal\n\n - `TextContent`: Simple text message\n - `MultiContent`: Message with multiple content parts (text and/or images)\nTextContent(String)\n\n\nMultiContent(List(ContentPart))\n\n\nSynonyms:\ngleamstral/message.MessageContent\ngleamstral/message MessageContent","url":"gleamstral/message.html#MessageContent"},{"doc":"gleamstral/message","title":"MessageRole","content":"pub type MessageRole {\n  System\n  User\n  Assistant\n  Tool\n}\n Represents the role of a message in a conversation\n\n - `System`: System messages provide context and instructions to the model\n - `User`: User messages represent the human interacting with the model\n - `Assistant`: Assistant messages are the model&#39;s responses\n - `Tool`: Tool messages contain the results of tool function calls\nSystem\n\n\nUser\n\n\nAssistant\n\n\nTool\n\n\nSynonyms:\ngleamstral/message.MessageRole\ngleamstral/message MessageRole","url":"gleamstral/message.html#MessageRole"},{"doc":"gleamstral/message","title":"message_decoder","content":"pub fn message_decoder() -&gt; Decoder(Message)\n\nSynonyms:\ngleamstral/message.message_decoder\ngleamstral/message message_decoder","url":"gleamstral/message.html#message_decoder"},{"doc":"gleamstral/message","title":"message_encoder","content":"pub fn message_encoder(message: Message) -&gt; Json\n\nSynonyms:\ngleamstral/message.message_encoder\ngleamstral/message message_encoder","url":"gleamstral/message.html#message_encoder"},{"doc":"gleamstral/message","title":"gleamstral/message","content":"","url":"gleamstral/message.html"},{"doc":"gleamstral/agent/response","title":"ChatCompletionChoice","content":"pub type ChatCompletionChoice {\n  ChatCompletionChoice(\n    index: Int,\n    message: message.Message,\n    finish_reason: FinishReason,\n  )\n}\n\nChatCompletionChoice(\n  index: Int,\n  message: message.Message,\n  finish_reason: FinishReason,\n)\n\n\nSynonyms:\ngleamstral/agent/response.ChatCompletionChoice\ngleamstral/agent/response ChatCompletionChoice","url":"gleamstral/agent/response.html#ChatCompletionChoice"},{"doc":"gleamstral/agent/response","title":"FinishReason","content":"pub type FinishReason {\n  Stop\n  Length\n  ModelLength\n  Err\n  ToolCalls\n}\n\nStop\n\n\nLength\n\n\nModelLength\n\n\nErr\n\n\nToolCalls\n\n\nSynonyms:\ngleamstral/agent/response.FinishReason\ngleamstral/agent/response FinishReason","url":"gleamstral/agent/response.html#FinishReason"},{"doc":"gleamstral/agent/response","title":"Response","content":"pub type Response {\n  Response(\n    id: String,\n    object: String,\n    created: Int,\n    model: String,\n    choices: List(ChatCompletionChoice),\n    usage: Usage,\n  )\n}\n\nResponse(\n  id: String,\n  object: String,\n  created: Int,\n  model: String,\n  choices: List(ChatCompletionChoice),\n  usage: Usage,\n)\n\n\nSynonyms:\ngleamstral/agent/response.Response\ngleamstral/agent/response Response","url":"gleamstral/agent/response.html#Response"},{"doc":"gleamstral/agent/response","title":"Usage","content":"pub type Usage {\n  Usage(\n    prompt_tokens: Int,\n    completion_tokens: Int,\n    total_tokens: Int,\n  )\n}\n\nUsage(\n  prompt_tokens: Int,\n  completion_tokens: Int,\n  total_tokens: Int,\n)\n\n\nSynonyms:\ngleamstral/agent/response.Usage\ngleamstral/agent/response Usage","url":"gleamstral/agent/response.html#Usage"},{"doc":"gleamstral/agent/response","title":"response_decoder","content":"pub fn response_decoder() -&gt; Decoder(Response)\n\nSynonyms:\ngleamstral/agent/response.response_decoder\ngleamstral/agent/response response_decoder","url":"gleamstral/agent/response.html#response_decoder"},{"doc":"gleamstral/agent/response","title":"gleamstral/agent/response","content":"","url":"gleamstral/agent/response.html"},{"doc":"gleamstral/client","title":"Client","content":"pub type Client {\n  Client(api_key: String)\n}\n Client for interacting with the Mistral AI API\n\n Contains the API key required for authentication\nClient(api_key: String)\n\n\nSynonyms:\ngleamstral/client.Client\ngleamstral/client Client","url":"gleamstral/client.html#Client"},{"doc":"gleamstral/client","title":"Error","content":"pub type Error {\n  RateLimitExceeded\n  Unauthorized\n  Unknown(String)\n}\n Represents possible errors that can occur when interacting with the Mistral AI API\n\n - `RateLimitExceeded`: Returned when API rate limits have been reached\n - `Unauthorized`: Returned when API key is invalid or missing\n - `Unknown`: Returned for any other error, with the error message as a string\nRateLimitExceeded\n\n\nUnauthorized\n\n\nUnknown(String)\n\n\nSynonyms:\ngleamstral/client.Error\ngleamstral/client Error","url":"gleamstral/client.html#Error"},{"doc":"gleamstral/client","title":"api_endpoint","content":"pub const api_endpoint: String\n\nSynonyms:\ngleamstral/client.api_endpoint\ngleamstral/client api_endpoint","url":"gleamstral/client.html#api_endpoint"},{"doc":"gleamstral/client","title":"error_decoder","content":"pub fn error_decoder() -&gt; Decoder(Error)\n\nSynonyms:\ngleamstral/client.error_decoder\ngleamstral/client error_decoder","url":"gleamstral/client.html#error_decoder"},{"doc":"gleamstral/client","title":"new","content":"pub fn new(api_key: String) -&gt; Client\n Creates a new Mistral AI client with the provided API key\n\n ## Example\n\n \n let client = client.new(&quot;your-api-key-here&quot;)\n \nSynonyms:\ngleamstral/client.new\ngleamstral/client new","url":"gleamstral/client.html#new"},{"doc":"gleamstral/client","title":"gleamstral/client","content":"","url":"gleamstral/client.html"},{"doc":"gleamstral/agent/agent","title":"Agent","content":"pub type Agent {\n  Agent(client: client.Client, config: Config)\n}\n Represents an agent with configuration options for communication with Mistral AI agents\nAgent(client: client.Client, config: Config)\n\n\nSynonyms:\ngleamstral/agent/agent.Agent\ngleamstral/agent/agent Agent","url":"gleamstral/agent/agent.html#Agent"},{"doc":"gleamstral/agent/agent","title":"Config","content":"pub type Config {\n  Config(\n    max_tokens: Int,\n    stream: Bool,\n    stop: List(String),\n    random_seed: Int,\n    response_format: ResponseFormat,\n    tools: List(tool.Tool),\n    tool_choice: tool.ToolChoice,\n    presence_penalty: Float,\n    frequency_penalty: Float,\n    n: Int,\n    prediction: Prediction,\n  )\n}\n\nConfig(\n  max_tokens: Int,\n  stream: Bool,\n  stop: List(String),\n  random_seed: Int,\n  response_format: ResponseFormat,\n  tools: List(tool.Tool),\n  tool_choice: tool.ToolChoice,\n  presence_penalty: Float,\n  frequency_penalty: Float,\n  n: Int,\n  prediction: Prediction,\n)\n\n\nSynonyms:\ngleamstral/agent/agent.Config\ngleamstral/agent/agent Config","url":"gleamstral/agent/agent.html#Config"},{"doc":"gleamstral/agent/agent","title":"Prediction","content":"pub type Prediction {\n  Content(String)\n}\n\nContent(String)\n\n\nSynonyms:\ngleamstral/agent/agent.Prediction\ngleamstral/agent/agent Prediction","url":"gleamstral/agent/agent.html#Prediction"},{"doc":"gleamstral/agent/agent","title":"ResponseFormat","content":"pub type ResponseFormat {\n  JsonObject\n  Text\n}\n\nJsonObject\n\n\nText\n\n\nSynonyms:\ngleamstral/agent/agent.ResponseFormat\ngleamstral/agent/agent ResponseFormat","url":"gleamstral/agent/agent.html#ResponseFormat"},{"doc":"gleamstral/agent/agent","title":"complete","content":"pub fn complete(\n  agent: Agent,\n  agent_id: String,\n  messages: List(Message),\n) -&gt; Result(Response, Error)\n Sends an agent completion request to the API and returns the response\n\n ### Parameters\n\n - `agent`: The configured Agent instance\n - `agent_id`: The ID of the Mistral AI agent to interact with\n - `messages`: The conversation history as a list of messages\n\n ### Returns\n\n - `Ok(response.Response)`: The successful response from the API\n - `Error(client.Error)`: An error that occurred during the request\n\n ### Example\n\n \n let result = agent\n   |&gt; agent.set_max_tokens(1000)\n   |&gt; agent.complete(&quot;agent-123&quot;, messages)\n \nSynonyms:\ngleamstral/agent/agent.complete\ngleamstral/agent/agent complete","url":"gleamstral/agent/agent.html#complete"},{"doc":"gleamstral/agent/agent","title":"new","content":"pub fn new(client: Client) -&gt; Agent\n Creates a new Agent with default configuration using the provided client\n\n ### Example\n\n \n let client = client.new(&quot;your-api-key&quot;)\n let agent = agent.new(client)\n \nSynonyms:\ngleamstral/agent/agent.new\ngleamstral/agent/agent new","url":"gleamstral/agent/agent.html#new"},{"doc":"gleamstral/agent/agent","title":"set_frequency_penalty","content":"pub fn set_frequency_penalty(\n  agent: Agent,\n  frequency_penalty: Float,\n) -&gt; Agent\n\nSynonyms:\ngleamstral/agent/agent.set_frequency_penalty\ngleamstral/agent/agent set_frequency_penalty","url":"gleamstral/agent/agent.html#set_frequency_penalty"},{"doc":"gleamstral/agent/agent","title":"set_max_tokens","content":"pub fn set_max_tokens(agent: Agent, max_tokens: Int) -&gt; Agent\n\nSynonyms:\ngleamstral/agent/agent.set_max_tokens\ngleamstral/agent/agent set_max_tokens","url":"gleamstral/agent/agent.html#set_max_tokens"},{"doc":"gleamstral/agent/agent","title":"set_n","content":"pub fn set_n(agent: Agent, n: Int) -&gt; Agent\n\nSynonyms:\ngleamstral/agent/agent.set_n\ngleamstral/agent/agent set_n","url":"gleamstral/agent/agent.html#set_n"},{"doc":"gleamstral/agent/agent","title":"set_prediction","content":"pub fn set_prediction(\n  agent: Agent,\n  prediction: Prediction,\n) -&gt; Agent\n\nSynonyms:\ngleamstral/agent/agent.set_prediction\ngleamstral/agent/agent set_prediction","url":"gleamstral/agent/agent.html#set_prediction"},{"doc":"gleamstral/agent/agent","title":"set_presence_penalty","content":"pub fn set_presence_penalty(\n  agent: Agent,\n  presence_penalty: Float,\n) -&gt; Agent\n\nSynonyms:\ngleamstral/agent/agent.set_presence_penalty\ngleamstral/agent/agent set_presence_penalty","url":"gleamstral/agent/agent.html#set_presence_penalty"},{"doc":"gleamstral/agent/agent","title":"set_random_seed","content":"pub fn set_random_seed(agent: Agent, random_seed: Int) -&gt; Agent\n\nSynonyms:\ngleamstral/agent/agent.set_random_seed\ngleamstral/agent/agent set_random_seed","url":"gleamstral/agent/agent.html#set_random_seed"},{"doc":"gleamstral/agent/agent","title":"set_response_format","content":"pub fn set_response_format(\n  agent: Agent,\n  response_format: ResponseFormat,\n) -&gt; Agent\n\nSynonyms:\ngleamstral/agent/agent.set_response_format\ngleamstral/agent/agent set_response_format","url":"gleamstral/agent/agent.html#set_response_format"},{"doc":"gleamstral/agent/agent","title":"set_stop","content":"pub fn set_stop(agent: Agent, stop: List(String)) -&gt; Agent\n\nSynonyms:\ngleamstral/agent/agent.set_stop\ngleamstral/agent/agent set_stop","url":"gleamstral/agent/agent.html#set_stop"},{"doc":"gleamstral/agent/agent","title":"set_stream","content":"pub fn set_stream(agent: Agent, stream: Bool) -&gt; Agent\n\nSynonyms:\ngleamstral/agent/agent.set_stream\ngleamstral/agent/agent set_stream","url":"gleamstral/agent/agent.html#set_stream"},{"doc":"gleamstral/agent/agent","title":"set_tool_choice","content":"pub fn set_tool_choice(\n  agent: Agent,\n  tool_choice: ToolChoice,\n) -&gt; Agent\n\nSynonyms:\ngleamstral/agent/agent.set_tool_choice\ngleamstral/agent/agent set_tool_choice","url":"gleamstral/agent/agent.html#set_tool_choice"},{"doc":"gleamstral/agent/agent","title":"set_tools","content":"pub fn set_tools(agent: Agent, tools: List(Tool)) -&gt; Agent\n\nSynonyms:\ngleamstral/agent/agent.set_tools\ngleamstral/agent/agent set_tools","url":"gleamstral/agent/agent.html#set_tools"},{"doc":"gleamstral/agent/agent","title":"gleamstral/agent/agent","content":"","url":"gleamstral/agent/agent.html"},{"doc":"gleamstral/chat/response","title":"ChatCompletionChoice","content":"pub type ChatCompletionChoice {\n  ChatCompletionChoice(\n    index: Int,\n    message: message.Message,\n    finish_reason: FinishReason,\n  )\n}\n\nChatCompletionChoice(\n  index: Int,\n  message: message.Message,\n  finish_reason: FinishReason,\n)\n\n\nSynonyms:\ngleamstral/chat/response.ChatCompletionChoice\ngleamstral/chat/response ChatCompletionChoice","url":"gleamstral/chat/response.html#ChatCompletionChoice"},{"doc":"gleamstral/chat/response","title":"FinishReason","content":"pub type FinishReason {\n  Stop\n  Length\n  ModelLength\n  Err\n  ToolCalls\n}\n\nStop\n\n\nLength\n\n\nModelLength\n\n\nErr\n\n\nToolCalls\n\n\nSynonyms:\ngleamstral/chat/response.FinishReason\ngleamstral/chat/response FinishReason","url":"gleamstral/chat/response.html#FinishReason"},{"doc":"gleamstral/chat/response","title":"Response","content":"pub type Response {\n  Response(\n    id: String,\n    object: String,\n    created: Int,\n    model: String,\n    choices: List(ChatCompletionChoice),\n    usage: Usage,\n  )\n}\n\nResponse(\n  id: String,\n  object: String,\n  created: Int,\n  model: String,\n  choices: List(ChatCompletionChoice),\n  usage: Usage,\n)\n\n\nSynonyms:\ngleamstral/chat/response.Response\ngleamstral/chat/response Response","url":"gleamstral/chat/response.html#Response"},{"doc":"gleamstral/chat/response","title":"Usage","content":"pub type Usage {\n  Usage(\n    prompt_tokens: Int,\n    completion_tokens: Int,\n    total_tokens: Int,\n  )\n}\n\nUsage(\n  prompt_tokens: Int,\n  completion_tokens: Int,\n  total_tokens: Int,\n)\n\n\nSynonyms:\ngleamstral/chat/response.Usage\ngleamstral/chat/response Usage","url":"gleamstral/chat/response.html#Usage"},{"doc":"gleamstral/chat/response","title":"response_decoder","content":"pub fn response_decoder() -&gt; Decoder(Response)\n\nSynonyms:\ngleamstral/chat/response.response_decoder\ngleamstral/chat/response response_decoder","url":"gleamstral/chat/response.html#response_decoder"},{"doc":"gleamstral/chat/response","title":"gleamstral/chat/response","content":"","url":"gleamstral/chat/response.html"},{"doc":"gleamstral/model","title":"Model","content":"pub type Model {\n  MistralLarge\n  MistralSmall\n  Ministral3B\n  Ministral8B\n  PixtralLarge\n  Pixtral\n  MistralEmbed\n  MistralNemo\n  MistralSaba\n}\n\nMistralLarge\n\n\nMistralSmall\n\n\nMinistral3B\n\n\nMinistral8B\n\n\nPixtralLarge\n\n\nPixtral\n\n\nMistralEmbed\n\n\nMistralNemo\n\n\nMistralSaba\n\n\nSynonyms:\ngleamstral/model.Model\ngleamstral/model Model","url":"gleamstral/model.html#Model"},{"doc":"gleamstral/model","title":"model_decoder","content":"pub fn model_decoder() -&gt; Decoder(Model)\n\nSynonyms:\ngleamstral/model.model_decoder\ngleamstral/model model_decoder","url":"gleamstral/model.html#model_decoder"},{"doc":"gleamstral/model","title":"to_string","content":"pub fn to_string(model: Model) -&gt; String\n\nSynonyms:\ngleamstral/model.to_string\ngleamstral/model to_string","url":"gleamstral/model.html#to_string"},{"doc":"gleamstral/model","title":"gleamstral/model","content":"","url":"gleamstral/model.html"},{"doc":"gleamstral/chat/chat","title":"Chat","content":"pub type Chat {\n  Chat(client: client.Client, config: Config)\n}\n Represents a chat conversation with configuration options\nChat(client: client.Client, config: Config)\n\n\nSynonyms:\ngleamstral/chat/chat.Chat\ngleamstral/chat/chat Chat","url":"gleamstral/chat/chat.html#Chat"},{"doc":"gleamstral/chat/chat","title":"Config","content":"pub type Config {\n  Config(\n    temperature: Float,\n    max_tokens: Int,\n    top_p: Float,\n    stream: Bool,\n    stop: List(String),\n    random_seed: Int,\n    response_format: ResponseFormat,\n    tools: List(tool.Tool),\n    tool_choice: tool.ToolChoice,\n    presence_penalty: Float,\n    frequency_penalty: Float,\n    n: Int,\n    prediction: Prediction,\n    safe_prompt: Bool,\n  )\n}\n\nConfig(\n  temperature: Float,\n  max_tokens: Int,\n  top_p: Float,\n  stream: Bool,\n  stop: List(String),\n  random_seed: Int,\n  response_format: ResponseFormat,\n  tools: List(tool.Tool),\n  tool_choice: tool.ToolChoice,\n  presence_penalty: Float,\n  frequency_penalty: Float,\n  n: Int,\n  prediction: Prediction,\n  safe_prompt: Bool,\n)\n\n\nSynonyms:\ngleamstral/chat/chat.Config\ngleamstral/chat/chat Config","url":"gleamstral/chat/chat.html#Config"},{"doc":"gleamstral/chat/chat","title":"Prediction","content":"pub type Prediction {\n  Content(String)\n}\n\nContent(String)\n\n\nSynonyms:\ngleamstral/chat/chat.Prediction\ngleamstral/chat/chat Prediction","url":"gleamstral/chat/chat.html#Prediction"},{"doc":"gleamstral/chat/chat","title":"ResponseFormat","content":"pub type ResponseFormat {\n  JsonObject\n  Text\n}\n\nJsonObject\n\n\nText\n\n\nSynonyms:\ngleamstral/chat/chat.ResponseFormat\ngleamstral/chat/chat ResponseFormat","url":"gleamstral/chat/chat.html#ResponseFormat"},{"doc":"gleamstral/chat/chat","title":"complete","content":"pub fn complete(\n  chat: Chat,\n  model: Model,\n  messages: List(Message),\n) -&gt; Result(Response, Error)\n Sends a chat completion request to the API and returns the response\n\n ### Parameters\n\n - `chat`: The configured Chat instance\n - `model`: The model to use for the completion\n - `messages`: The conversation history as a list of messages\n\n ### Returns\n\n - `Ok(response.Response)`: The successful response from the API\n - `Error(client.Error)`: An error that occurred during the request\n\n ### Example\n\n \n let result = chat\n   |&gt; chat.set_temperature(0.7)\n   |&gt; chat.complete(model.MistralSmall, messages)\n \nSynonyms:\ngleamstral/chat/chat.complete\ngleamstral/chat/chat complete","url":"gleamstral/chat/chat.html#complete"},{"doc":"gleamstral/chat/chat","title":"new","content":"pub fn new(client: Client) -&gt; Chat\n Creates a new Chat with default configuration using the provided client\n\n ## Example\n\n \n let client = client.new(&quot;your-api-key&quot;)\n let chat = chat.new(client)\n \nSynonyms:\ngleamstral/chat/chat.new\ngleamstral/chat/chat new","url":"gleamstral/chat/chat.html#new"},{"doc":"gleamstral/chat/chat","title":"set_frequency_penalty","content":"pub fn set_frequency_penalty(\n  chat: Chat,\n  frequency_penalty: Float,\n) -&gt; Chat\n\nSynonyms:\ngleamstral/chat/chat.set_frequency_penalty\ngleamstral/chat/chat set_frequency_penalty","url":"gleamstral/chat/chat.html#set_frequency_penalty"},{"doc":"gleamstral/chat/chat","title":"set_max_tokens","content":"pub fn set_max_tokens(chat: Chat, max_tokens: Int) -&gt; Chat\n\nSynonyms:\ngleamstral/chat/chat.set_max_tokens\ngleamstral/chat/chat set_max_tokens","url":"gleamstral/chat/chat.html#set_max_tokens"},{"doc":"gleamstral/chat/chat","title":"set_n","content":"pub fn set_n(chat: Chat, n: Int) -&gt; Chat\n\nSynonyms:\ngleamstral/chat/chat.set_n\ngleamstral/chat/chat set_n","url":"gleamstral/chat/chat.html#set_n"},{"doc":"gleamstral/chat/chat","title":"set_prediction","content":"pub fn set_prediction(chat: Chat, prediction: Prediction) -&gt; Chat\n\nSynonyms:\ngleamstral/chat/chat.set_prediction\ngleamstral/chat/chat set_prediction","url":"gleamstral/chat/chat.html#set_prediction"},{"doc":"gleamstral/chat/chat","title":"set_presence_penalty","content":"pub fn set_presence_penalty(\n  chat: Chat,\n  presence_penalty: Float,\n) -&gt; Chat\n\nSynonyms:\ngleamstral/chat/chat.set_presence_penalty\ngleamstral/chat/chat set_presence_penalty","url":"gleamstral/chat/chat.html#set_presence_penalty"},{"doc":"gleamstral/chat/chat","title":"set_random_seed","content":"pub fn set_random_seed(chat: Chat, random_seed: Int) -&gt; Chat\n\nSynonyms:\ngleamstral/chat/chat.set_random_seed\ngleamstral/chat/chat set_random_seed","url":"gleamstral/chat/chat.html#set_random_seed"},{"doc":"gleamstral/chat/chat","title":"set_response_format","content":"pub fn set_response_format(\n  chat: Chat,\n  response_format: ResponseFormat,\n) -&gt; Chat\n\nSynonyms:\ngleamstral/chat/chat.set_response_format\ngleamstral/chat/chat set_response_format","url":"gleamstral/chat/chat.html#set_response_format"},{"doc":"gleamstral/chat/chat","title":"set_safe_prompt","content":"pub fn set_safe_prompt(chat: Chat, safe_prompt: Bool) -&gt; Chat\n\nSynonyms:\ngleamstral/chat/chat.set_safe_prompt\ngleamstral/chat/chat set_safe_prompt","url":"gleamstral/chat/chat.html#set_safe_prompt"},{"doc":"gleamstral/chat/chat","title":"set_stop","content":"pub fn set_stop(chat: Chat, stop: List(String)) -&gt; Chat\n\nSynonyms:\ngleamstral/chat/chat.set_stop\ngleamstral/chat/chat set_stop","url":"gleamstral/chat/chat.html#set_stop"},{"doc":"gleamstral/chat/chat","title":"set_stream","content":"pub fn set_stream(chat: Chat, stream: Bool) -&gt; Chat\n\nSynonyms:\ngleamstral/chat/chat.set_stream\ngleamstral/chat/chat set_stream","url":"gleamstral/chat/chat.html#set_stream"},{"doc":"gleamstral/chat/chat","title":"set_temperature","content":"pub fn set_temperature(chat: Chat, temperature: Float) -&gt; Chat\n\nSynonyms:\ngleamstral/chat/chat.set_temperature\ngleamstral/chat/chat set_temperature","url":"gleamstral/chat/chat.html#set_temperature"},{"doc":"gleamstral/chat/chat","title":"set_tool_choice","content":"pub fn set_tool_choice(\n  chat: Chat,\n  tool_choice: ToolChoice,\n) -&gt; Chat\n\nSynonyms:\ngleamstral/chat/chat.set_tool_choice\ngleamstral/chat/chat set_tool_choice","url":"gleamstral/chat/chat.html#set_tool_choice"},{"doc":"gleamstral/chat/chat","title":"set_tools","content":"pub fn set_tools(chat: Chat, tools: List(Tool)) -&gt; Chat\n\nSynonyms:\ngleamstral/chat/chat.set_tools\ngleamstral/chat/chat set_tools","url":"gleamstral/chat/chat.html#set_tools"},{"doc":"gleamstral/chat/chat","title":"set_top_p","content":"pub fn set_top_p(chat: Chat, top_p: Float) -&gt; Chat\n\nSynonyms:\ngleamstral/chat/chat.set_top_p\ngleamstral/chat/chat set_top_p","url":"gleamstral/chat/chat.html#set_top_p"},{"doc":"gleamstral/chat/chat","title":"gleamstral/chat/chat","content":"","url":"gleamstral/chat/chat.html"},{"doc":"gleamstral/embeddings/response","title":"EmbeddingData","content":"pub type EmbeddingData {\n  EmbeddingData(index: Int, embedding: List(Float))\n}\n\nEmbeddingData(index: Int, embedding: List(Float))\n\n\nSynonyms:\ngleamstral/embeddings/response.EmbeddingData\ngleamstral/embeddings/response EmbeddingData","url":"gleamstral/embeddings/response.html#EmbeddingData"},{"doc":"gleamstral/embeddings/response","title":"Response","content":"pub type Response {\n  Response(\n    id: String,\n    object: String,\n    data: List(EmbeddingData),\n    model: String,\n    usage: Usage,\n  )\n}\n\nResponse(\n  id: String,\n  object: String,\n  data: List(EmbeddingData),\n  model: String,\n  usage: Usage,\n)\n\n\nSynonyms:\ngleamstral/embeddings/response.Response\ngleamstral/embeddings/response Response","url":"gleamstral/embeddings/response.html#Response"},{"doc":"gleamstral/embeddings/response","title":"Usage","content":"pub type Usage {\n  Usage(prompt_tokens: Int, total_tokens: Int)\n}\n\nUsage(prompt_tokens: Int, total_tokens: Int)\n\n\nSynonyms:\ngleamstral/embeddings/response.Usage\ngleamstral/embeddings/response Usage","url":"gleamstral/embeddings/response.html#Usage"},{"doc":"gleamstral/embeddings/response","title":"response_decoder","content":"pub fn response_decoder() -&gt; Decoder(Response)\n\nSynonyms:\ngleamstral/embeddings/response.response_decoder\ngleamstral/embeddings/response response_decoder","url":"gleamstral/embeddings/response.html#response_decoder"},{"doc":"gleamstral/embeddings/response","title":"gleamstral/embeddings/response","content":"","url":"gleamstral/embeddings/response.html"},{"doc":"gleamstral/embeddings/embeddings","title":"Config","content":"pub type Config {\n  Config(encoding_format: EncodingFormat)\n}\n\nConfig(encoding_format: EncodingFormat)\n\n\nSynonyms:\ngleamstral/embeddings/embeddings.Config\ngleamstral/embeddings/embeddings Config","url":"gleamstral/embeddings/embeddings.html#Config"},{"doc":"gleamstral/embeddings/embeddings","title":"Embeddings","content":"pub type Embeddings {\n  Embeddings(client: client.Client, config: Config)\n}\n Represents an embeddings service with configuration options\n\n Use this to generate vector embeddings for text inputs\nEmbeddings(client: client.Client, config: Config)\n\n\nSynonyms:\ngleamstral/embeddings/embeddings.Embeddings\ngleamstral/embeddings/embeddings Embeddings","url":"gleamstral/embeddings/embeddings.html#Embeddings"},{"doc":"gleamstral/embeddings/embeddings","title":"EncodingFormat","content":"pub type EncodingFormat {\n  Float\n}\n Format of the generated embeddings\n\n - `Float`: Standard floating point format for vector embeddings\nFloat\n\n\nSynonyms:\ngleamstral/embeddings/embeddings.EncodingFormat\ngleamstral/embeddings/embeddings EncodingFormat","url":"gleamstral/embeddings/embeddings.html#EncodingFormat"},{"doc":"gleamstral/embeddings/embeddings","title":"create","content":"pub fn create(\n  embeddings: Embeddings,\n  model: Model,\n  inputs: List(String),\n) -&gt; Result(Response, Error)\n Generates embeddings for the provided text inputs\n\n ### Parameters\n\n - `embeddings`: The configured Embeddings instance\n - `model`: The model to use for generating embeddings\n - `inputs`: A list of text strings to generate embeddings for\n\n ### Returns\n\n - `Ok(response.Response)`: The successful response containing embeddings\n - `Error(client.Error)`: An error that occurred during the request\n\n ### Example\n\n \n let result = embeddings.create(\n   embeddings,\n   model.EmbeddingMistral,\n   [&quot;Text to embed&quot;, &quot;Another text to embed&quot;]\n )\n \nSynonyms:\ngleamstral/embeddings/embeddings.create\ngleamstral/embeddings/embeddings create","url":"gleamstral/embeddings/embeddings.html#create"},{"doc":"gleamstral/embeddings/embeddings","title":"new","content":"pub fn new(client: Client) -&gt; Embeddings\n Creates a new Embeddings instance with default configuration using the provided client\n\n ### Example\n\n \n let client = client.new(&quot;your-api-key&quot;)\n let embeddings = embeddings.new(client)\n \nSynonyms:\ngleamstral/embeddings/embeddings.new\ngleamstral/embeddings/embeddings new","url":"gleamstral/embeddings/embeddings.html#new"},{"doc":"gleamstral/embeddings/embeddings","title":"set_encoding_format","content":"pub fn set_encoding_format(\n  embeddings: Embeddings,\n  encoding_format: EncodingFormat,\n) -&gt; Embeddings\n\nSynonyms:\ngleamstral/embeddings/embeddings.set_encoding_format\ngleamstral/embeddings/embeddings set_encoding_format","url":"gleamstral/embeddings/embeddings.html#set_encoding_format"},{"doc":"gleamstral/embeddings/embeddings","title":"gleamstral/embeddings/embeddings","content":"","url":"gleamstral/embeddings/embeddings.html"}]);